OC.L10N.register(
    "core",
    {
    "Please select a file." : "Bonvolu elekti dosieron.",
    "File is too big" : "Dosiero tro grandas",
    "The selected file is not an image." : "La elektita dosiero ne estas bildo.",
    "The selected file cannot be read." : "La elektita dosiero ne estas legebla.",
    "The file was uploaded" : "La dosiero alŝutiĝis",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "La dosiero alŝutita superas la regulon „upload_max_filesize“ el „php.ini“",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "La dosiero alŝutita superas la regulon MAX_FILE_SIZE, kiu estas difinita en la HTML-formularo",
    "The file was only partially uploaded" : "La dosiero alŝutiĝis nur parte",
    "No file was uploaded" : "Neniu dosiero alŝutiĝis",
    "Missing a temporary folder" : "Mankas provizora dosierujo",
    "Could not write file to disk" : "Ne eblis skribi dosieron sur diskon",
    "A PHP extension stopped the file upload" : "PHP-modulo haltigis la dosieralŝuton",
    "Invalid file provided" : "Nevalida dosiero provizita",
    "No image or file provided" : "Neniu bildo aŭ dosiero provizita",
    "Unknown filetype" : "Nekonata dosiertipo",
    "An error occurred. Please contact your admin." : "Eraro okazis. Bonvolu kontakti vian administranton.",
    "Invalid image" : "Nevalida bildo",
    "No temporary profile picture available, try again" : "Neniu provizora profilbildo disponeblas, bv. reprovi",
    "No crop data provided" : "Neniu stucdatumo provizita",
    "No valid crop data provided" : "Neniu valida stucdatumo provizita",
    "Crop is not square" : "Stuca elekto ne estas kvadrata",
    "State token does not match" : "Stata ĵetono ne kongruas",
    "Invalid app password" : "Nevalida aplikaĵo-pasvorto",
    "Could not complete login" : "Ensaluto ne eblis",
    "Your login token is invalid or has expired" : "Via ensaluta ĵetono ne validas aŭ senvalidiĝis",
    "Login" : "Login",
    "Password reset is disabled" : "Pasvorta restarigo malebligita",
    "Could not reset password because the token is expired" : "Ne eblis restarigi pasvorton, ĉar la ĵetono senvalidiĝis",
    "Could not reset password because the token is invalid" : "Ne eblis restarigi pasvorton, ĉar la ĵetono ne validas",
    "Password is too long. Maximum allowed length is 469 characters." : "La pasvorto tro longas. Ĝia maksimuma longo estas 469 signoj.",
    "%s password reset" : "Restarigo de pasvorto %s",
    "Password reset" : "Restarigi pasvorton",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Alklaku la jenan butonon por restarigi vian pasvorton. Si vi ne petis restarigon de via pasvorto, simple ignoru tiun ĉi retmesaĝon.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Alklaku la jenan ligilon por restarigi vian pasvorton. Si vi ne petis restarigon de via pasvorto, simple ignoru tiun ĉi retmesaĝon.",
    "Reset your password" : "Restarigi vian pasvorton ",
    "Task not found" : "Tasko ne trovita",
    "Internal error" : "Interna eraro",
    "Not found" : "Ne trovita",
    "Image not found" : "Bildo ne trovita",
    "Unable to translate" : "Ne eblas traduki",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Ripara stadio:",
    "Repair info:" : "Ripara informo:",
    "Repair warning:" : "Ripara averto:",
    "Repair error:" : "Ripara eraro:",
    "Nextcloud Server" : "Nextcloud-servilo",
    "Some of your link shares have been removed" : "Kelkaj el viaj kunhavigaj ligiloj estis forigitaj",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Pro sekuriga problemo, ni forigu kelkajn el viaj kunhavigaj ligiloj. Bv. vidi la ligilon por plia informo.",
    "Learn more ↗" : "Scii pli ↗",
    "Preparing update" : "Preparo de  la ĝisdatigo",
    "Turned on maintenance mode" : "Reĝimo de prizorgado ŝaltita.",
    "Turned off maintenance mode" : "Reĝimo de prizorgado malŝaltita.",
    "Maintenance mode is kept active" : "Reĝimo de prizorgado pluas",
    "Updating database schema" : "Ĝisdatigo de la skemo de la datumbazo",
    "Updated database" : "Ĝisdatiĝis datumbazo",
    "Update app \"%s\" from App Store" : "Ĝisdatigo de la aplikaĵo „%s“ el aplikaĵejo",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Kontrolo, ĉu la skemo de la datumbazo por %s estas ĝisdatigebla (tio povas daŭri longe laŭ la grando de la datumbazo)",
    "Updated \"%1$s\" to %2$s" : "„%1$s“ ĝisdatigita al %2$s",
    "Set log level to debug" : "Agordi la protokolnivelon je sencimigo",
    "Reset log level" : "Restarigi nivelon de protokolado",
    "Starting code integrity check" : "Kontrolo de koda integreco",
    "Finished code integrity check" : "Fino de la kontrolo de koda integreco",
    "%s (incompatible)" : "%s (nekongrua)",
    "The following apps have been disabled: %s" : "La jenaj aplikaĵoj estis malŝatitaj: %s",
    "Already up to date" : "Jam aktuala",
    "Unknown" : "Nekonata",
    "Error occurred while checking server setup" : "Eraro dum kontrolo de servila agordo",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Por pliaj detaloj, vidu la {linkstart}dokumentaron ↗{linkend}.",
    "unknown text" : "nekonata teksto",
    "Hello world!" : "Saluton, mondo!",
    "sunny" : "suna",
    "Hello {name}, the weather is {weather}" : "Saluton {name}, la vetero estas {weather}",
    "Hello {name}" : "Saluton {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Jen via serĉ-rezultoj<script>alert(1)</script></strong>",
    "new" : "nova",
    "_download %n file_::_download %n files_" : ["elŝuti %n dosieron","elŝuti %n dosierojn"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Ĝisdatigo estas farata; forirado de la paĝo povas kelkfoje interrompi la agon.",
    "Update to {version}" : "Ĝisdatigi al {version}",
    "An error occurred." : "Eraro okazis.",
    "Please reload the page." : "Bonvolu reŝargi la paĝon.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "La ĝisdatigo malsukcesis. Por pli da informoj, <a href=\"{url}\">vidu la forumafisôn</a> pri tio.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "La ĝisdatigo malsukcesis. Bonvolu raporti tiun problemon al la <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud-komunumo</a>.",
    "Applications menu" : "Aplikaĵa menuo",
    "Apps" : "Aplikaĵoj",
    "More apps" : "Pli da aplikaĵoj",
    "_{count} notification_::_{count} notifications_" : ["{count} sciigoj","{count} sciigoj"],
    "No" : "Ne",
    "Yes" : "Jes",
    "Failed to add the public link to your Nextcloud" : "Ne eblis aldoni la publikan ligilon al via Nextcloud",
    "Custom date range" : "Propra data periodo",
    "Pick start date" : "Elekti komencan daton",
    "Pick end date" : "Elekti finan daton",
    "Search in date range" : "Serĉi en data periodo",
    "Searching …" : "Serĉado ...",
    "Start typing to search" : "Ektajpu por serĉi",
    "No matching results" : "Neniuj kongruaj rezultoj",
    "Today" : "Hodiaŭ",
    "Last 7 days" : "Lastaj 7 tagoj",
    "Last 30 days" : "Lastaj 30 tagoj",
    "This year" : "Ĉi jaro",
    "Last year" : "Lasta jaro",
    "Date" : "Dato",
    "Search people" : "Serĉi homojn",
    "People" : "Homoj",
    "Filter in current view" : "Filtrilo en ĉi vido",
    "Search in" : "Serĉi en",
    "Log in" : "Ensaluti",
    "Logging in …" : "Ensaluti...",
    "Log in to {productName}" : "Saluti al {productName}",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Ni eltrovis plurajn nevalidajn provojn ensaluti el via IP-adreso. Do, oni prokrastis vian sekvantan ensaluton dum ĝis 30 sekundoj.",
    "Account name or email" : "Kontonomo aŭ retpoŝta adreso",
    "Server side authentication failed!" : "Ĉeservila aŭtentigo malsukcesis!",
    "Please contact your administrator." : "Bonvolu kontakti vian administranton.",
    "An internal error occurred." : "Interna servileraro okazis.",
    "Please try again or contact your administrator." : "Bonvolu provi ree aŭ kontakti vian administranton.",
    "Password" : "Pasvorto",
    "Your account is not setup for passwordless login." : "Via konto ne estas agordita por uzi senpasvortan ensaluton.",
    "Your connection is not secure" : "La konekto ne sekuras",
    "Passwordless authentication is only available over a secure connection." : "Senpasvorta aŭtentigo eblas nur pere de sekura konekto.",
    "Passwordless authentication is not supported in your browser." : "Senpasvorta aŭtentigo ne eblas per via retumilo.",
    "Reset password" : "Restarigi pasvorton",
    "Back to login" : "Antaŭen al ensaluto",
    "Couldn't send reset email. Please contact your administrator." : "Ne eblas sendi retpoŝton pri restarigo. Bonvolu kontakti vian administranton.",
    "New password" : "Nova pasvorto",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Viaj dosieroj estas ĉifritaj. Ne estos eble rehavi viajn datumojn post la restarigo de via pasvorto. Se vi ne tute certas pri kio fari, bonvolu pridemandi vian administranton, antaŭ ol daŭrigi.  Ĉu vi ja volas daŭrigi?",
    "I know what I'm doing" : "Mi scias, kion mi faras",
    "Resetting password" : "Restarigo de la pasvorto",
    "Recommended apps" : "Rekomendataj aplikaĵoj",
    "Loading apps …" : "Ŝargado de aplikaĵoj...",
    "App download or installation failed" : "Elŝuto aŭ instalado de la aplikaĵo malsukcesis",
    "Cannot install this app" : "La instalado de tiu aplikaĵo ne eblas",
    "Skip" : "Preterpasi",
    "Installing apps …" : "Instalado de aplikaĵoj...",
    "Install recommended apps" : "Instali rekomendatajn aplikaĵojn",
    "Avatar of {displayName}" : "Avataro de {displayName}",
    "Settings menu" : "Menuo de agordo",
    "Loading your contacts …" : "Ŝargo de viaj kontaktoj...",
    "Looking for {term} …" : "Serĉo de {term}…",
    "Reset search" : "Restarigi serĉon",
    "Search contacts …" : "Serĉi kontaktojn…",
    "Could not load your contacts" : "Ne eblis ŝargi viajn kontaktojn",
    "No contacts found" : "Neniu kontakto troviĝis",
    "Install the Contacts app" : "Instali la Kontakto-aplikaĵon",
    "Search" : "Serĉi",
    "No results for {query}" : "Neniu rezulto pri {query}",
    "Forgot password?" : "Ĉu vi forgesis vian pasvorton?",
    "Back" : "Antaŭen",
    "More actions" : "Pliaj agoj",
    "Security warning" : "Sekureca averto",
    "Storage & database" : "Konservejo kaj datumbazo",
    "Data folder" : "Datuma dosierujo",
    "Install and activate additional PHP modules to choose other database types." : "Instalu kaj aktivigu pliajn PHP-modulojn por elekti aliajn datumbazajn specojn..",
    "For more details check out the documentation." : "Por pli detaloj, vidu la dokumentaron.",
    "Performance warning" : "Rendimenta averto",
    "You chose SQLite as database." : "Vi elektis datumbazon „SQLite“.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite estu nur uzita por minimuma kaj programista servilo. Por produkta medio, ni rekomendas uzi alian tipon de datumbazo.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Se vi uzas klientojn por sinkronigi dosierojn, oni ne rekomendas datumbazon SQLite.",
    "Database user" : "Datumbaza uzanto",
    "Database password" : "Datumbaza pasvorto",
    "Database name" : "Datumbaza nomo",
    "Database tablespace" : "Datumbaza tabelospaco",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Bv. entajpi la pordan numeron kune kun la gastiga nomo (ekzemple: localhost:5432).",
    "Database host" : "Datumbaza gastigo",
    "Installing …" : "Instalante…",
    "Install" : "Instali",
    "Need help?" : "Ĉu necesas helpo?",
    "See the documentation" : "Vidi la dokumentaron",
    "{name} version {version} and above" : "{name} versio {version} kaj supre",
    "This browser is not supported" : "La retumilo ne estas subtenata",
    "Continue with this unsupported browser" : "Daŭrigi per tiu ne subtenata retumilo",
    "Supported versions" : "Subtenataj versioj",
    "Choose {file}" : "Elekti {file}",
    "Choose" : "Elekti",
    "Copy to {target}" : "Kopii al {target}",
    "Copy" : "Kopii",
    "Move to {target}" : "Movi al {target}",
    "Move" : "Movi",
    "OK" : "Akcepti",
    "read-only" : "nurlega",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} dosierkonflikto","{count} dosierkonfliktoj"],
    "One file conflict" : "Unu dosierkonflikto",
    "New Files" : "Novaj dosieroj",
    "Already existing files" : "Jam ekzistantaj dosieroj",
    "Which files do you want to keep?" : "Kiujn dosierojn vi volas konservi?",
    "If you select both versions, the copied file will have a number added to its name." : "Se vi elektos ambaŭ eldonojn, la kopiota dosiero havos numeron aldonitan al sia nomo.",
    "Cancel" : "Nuligi",
    "Continue" : "Daŭrigi",
    "(all selected)" : "(ĉiuj elektitaj)",
    "({count} selected)" : "({count} elektitaj)",
    "Error loading file exists template" : "Eraris ŝargo de ŝablono pri ekzistanta dosiero",
    "Saving …" : "Konservado...",
    "seconds ago" : "sekundoj antaŭe",
    "Connection to server lost" : "Konekto al servilo perdita",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problemo dum ŝargo de paĝo, reŝargo en %n sekundo","Problemo dum ŝargo de paĝo, reŝargo en %n sekundoj"],
    "Add to a project" : "Aldoni al projekto",
    "Show details" : "Montri la detalojn",
    "Hide details" : "Kaŝi la detalojn",
    "Rename project" : "Alinomi la projekton",
    "Failed to rename the project" : "Malsukceso alinomi la projekton",
    "Failed to create a project" : "Malsukceso krei projekton",
    "Failed to add the item to the project" : "Malsukceso aldoni la elementon al la projekto",
    "Connect items to a project to make them easier to find" : "Konekti elementojn al projekto por faciligi ilian trovon",
    "Type to search for existing projects" : "Entajpi por serĉi jam ekzistantajn projektojn",
    "New in" : "Nova en",
    "View changelog" : "Vidi ŝanĝoprotokolon",
    "No action available" : "Neniu ago disponebla",
    "Error fetching contact actions" : "Eraro dum serĉo de kontakt-agoj",
    "Close \"{dialogTitle}\" dialog" : "Fermi la dialogon \"{dialogTitle}\"",
    "Non-existing tag #{tag}" : "Ne ekzistas etikedo #{tag}",
    "Restricted" : "Limigita",
    "Invisible" : "Nevidebla",
    "Delete" : "Forigi",
    "Rename" : "Alinomi",
    "Collaborative tags" : "Kunlaboraj etikedoj",
    "No tags found" : "Neniu etikedo troviĝis ",
    "Personal" : "Persona",
    "Accounts" : "Kontoj",
    "Admin" : "Administranto",
    "Help" : "Helpo",
    "Access forbidden" : "Aliro estas malpermesata",
    "Back to %s" : "Antaŭen al %s",
    "Page not found" : "Paĝo ne trovita",
    "The page could not be found on the server or you may not be allowed to view it." : "La paĝo ne povis esti trovita en la servilo aŭ vi eble ne rajtas vidi ĝin.",
    "Too many requests" : "Tro da petoj",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Estis tro multaj petoj de via reto. Reprovu poste aŭ kontaktu vian administranton se tio estas eraro.",
    "Error" : "Eraro",
    "Internal Server Error" : "Interna servileraro",
    "The server was unable to complete your request." : "La servilo ne eblis plenumi vian peton.",
    "If this happens again, please send the technical details below to the server administrator." : "Se tio denove okazos, bv. sendi la teĥnikajn detalojn ĉi-sube al la administranto de la servilo.",
    "More details can be found in the server log." : "Pli da detaloj troveblas en la servila protokolo.",
    "Technical details" : "Teĥnikaj detaloj",
    "Remote Address: %s" : "Fora adreso: %s",
    "Request ID: %s" : "Peta identigilo: %s",
    "Type: %s" : "Tipo: %s",
    "Code: %s" : "Kodo: %s",
    "Message: %s" : "Mesaĝo: %s",
    "File: %s" : "Dosiero: %s",
    "Line: %s" : "Linio: %s",
    "Trace" : "Spuro",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Ŝajnas, ke vi provas reinstali vian Nextcloud. Sed la dosiero CAN_INSTALL (angle por „eblo instali“) mankas en via dosierujo „config“. Bv. krei dosieron CAN_INSTALL ene de via dosierujo „config“ por daŭrigi.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Ne eblis forigi la dosieron „CAN_INSTALL“ el via dosierujo „config“. Bv. forigi ĝin permane.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Tiu aplikaĵo bezonas Ĝavoskripton („Javascript“) por funkcii. Bonvolu {linkstart}ŝalti Ĝavoskripton{linkend} kaj poste reŝargi la paĝon.",
    "Skip to main content" : "Iru al la ĉefa enhavo",
    "Skip to navigation of app" : "Iru al la aplikaĵa navigado",
    "Go to %s" : "Iri al %s",
    "Get your own free account" : "Ekhavu vian propran senpagan konton",
    "Connect to your account" : "Konekti al via konto",
    "Please log in before granting %1$s access to your %2$s account." : "Bv. unue ensaluti por doni al %1$s aliron al via konto %2$s.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Se vi ne provas agordi novan aparaton aŭ apon, iu provas trompi vin por doni al ili aliron al viaj datumoj. En ĉi tiu kazo ne procedu kaj anstataŭe kontaktu vian sisteman administranton.",
    "App password" : "Aplikaĵa pasvorto",
    "Grant access" : "Doni alirpermeson",
    "Account access" : "Aliro al konto",
    "Currently logged in as %1$s (%2$s)." : "Aktuale salutinta kiel %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Vi tuj donos permeson al %1$s aliri al via konto %2$s.",
    "Account connected" : "Konto konektita",
    "Your client should now be connected!" : "Via kliento estas konektita!",
    "You can close this window." : "Vi povas fermi tiun ĉi fenestron.",
    "Previous" : "Antaŭa",
    "This share is password-protected" : "Tiu kunhavigo estas protektata per pasvorto",
    "The password is wrong or expired. Please try again or request a new one." : "La pasvorto estas malĝusta aŭ eksvalidiĝis. Bonvolu provi denove aŭ peti novan.",
    "Email address" : "Retpoŝtadreso",
    "Password sent!" : "Pasvorto sendiĝis!",
    "Two-factor authentication" : "Dufaza aŭtentigo",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Plibonigita sekurigo estas ebligita por via konto. Elektu duan fazon por aŭtentigo:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Ne eblis ŝargi almenaŭ unu el viaj ebligitaj metodoj pri dufaza aŭtentigo. Bv. kontakti vian administranton.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Dufaza aŭtentigo estas ebligita, sed ĝi ne estis agordita por via konto. Kontakti vian administranton por helpo.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Dufaza aŭtentigo estas ebligita, sed ĝi ne estis agordita por via konto. Bv. daŭrigi por agordi ĝin.",
    "Set up two-factor authentication" : "Agordi dufazan aŭtentigon",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Dufaza aŭtentigo estas ebligita, sed ĝi ne estis agordita por via konto. Uzu unu el viaj rezervkodoj por ensaluti, aŭ kontaktu vian administranton por helpo.",
    "Use backup code" : "Uzi rezervkodon",
    "Cancel login" : "Nuligi ensaluton",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Plibonigita sekurigo estas devigata por via konto. Elektu provizanton agordotan:",
    "Error while validating your second factor" : "Eraro dum validigo de via dua fazo",
    "Access through untrusted domain" : "Aliro tra nefidinda domajno",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Bv. kontakti vian administranton. Se vi estas administranto, modifu la agordon „trusted_domains“ (fidindaj domajnoj en la angla) en la dosiero config/config.php (estas ekzemplo en config.sample.php).",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Pliaj informoj pri agordo de tio troveblas en la %1$sdokumentaro%2$s.",
    "App update required" : "Aplikaĵa ĝisdatigo nepras",
    "%1$s will be updated to version %2$s" : "%1$s ĝisdatiĝos al versio %2$s",
    "The following apps will be updated:" : "La jenaj aplikaĵoj estos ĝisdatigitaj:",
    "These incompatible apps will be disabled:" : "La jenaj malkongruaj aplikaĵoj estos malŝaltataj:",
    "The theme %s has been disabled." : "La etoso %s estis malebligita.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Bonvolu certiĝi, ke la datumbazo, la dosierujo de agordoj kaj la dosierujo de datumoj jam estis savkopiitaj antaŭ ol plui.",
    "Start update" : "Ekĝisdatigi",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Por eviti eltempiĝon ĉe grandaj instalaĵoj, vi povas anstataŭe ruli la jenan komandon en via instalo-dosierujo:",
    "Detailed logs" : "Detalaj protokoloj",
    "Update needed" : "Bezonas ĝisdatigi",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Vidu la  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentaron</a> por helpo.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Mi scias, ke, se mi daŭrigas la ĝisdatigon per la reteja fasado, estas risko, ke la peto eltempiĝos kaj okazigos perdon de datumoj. Sed, mi havas sekurkopion kaj scias, kiel restaŭri mian servilon okaze de paneo.",
    "Upgrade via web on my own risk" : "Ĝisdatigi per reteja fasado je mia risko",
    "Maintenance mode" : "Reĝimo de prizorgado",
    "This %s instance is currently in maintenance mode, which may take a while." : "La servilo %s estas nun en reĝimo de prizorgado, tio eble daŭros longatempe.",
    "This page will refresh itself when the instance is available again." : "Tiu ĉi paĝo aktualiĝos mem, kiam la servilo redisponeblos.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontaktu vian administranton, se tiu ĉi mesaĝo daŭras aŭ aperas neatendite.",
    "Edit Profile" : "Modifi profilon",
    "Very weak password" : "Tre malforta pasvorto",
    "Weak password" : "Malforta pasvorto",
    "So-so password" : "Mezbona pasvorto",
    "Good password" : "Bona pasvorto",
    "Strong password" : "Forta pasvorto",
    "Profile not found" : "Profilo ne troviĝis",
    "The profile does not exist." : "La profilo ne ekzistas.",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Via datumdosierujo kaj dosieroj estas probable elireblaj el la interreto, ĉar la dosiero „.htaccess“ ne funkcias.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Por pli da informoj pri kielo agordi vian retservilon, bv. vidi la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentaron</a>.",
    "Show password" : "Montri pasvorton",
    "Toggle password visibility" : "Ŝanĝi videblecon de pasvorto",
    "Configure the database" : "Agordi la datumbazon",
    "Only %s is available." : "Nur %s disponeblas.",
    "Database account" : "Datumbaza konto"
},
"nplurals=2; plural=(n != 1);");
